<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Nastavenia Runneru</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Vzhľad</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Poloha:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Top margin</source>
        <translation>Horný okraj</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="43"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="50"/>
        <source>Width:</source>
        <translation>Šírka:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="57"/>
        <source>With multiple screens, if the window is shown on the focused screen,
this value is only for the smallest screen. The minimum width is 400 px.</source>
        <translation>Ak je okno zobrazené na cieľovej obrazovke,
táto hodnota sa vzťahuje len na najmenšiu obrazovku. Minimálna šírka je 400 bodov.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="61"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="71"/>
        <source>Show on:</source>
        <translation>Kde zobrazovať:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="108"/>
        <source>Show history first</source>
        <translation>Históriu zobrazovať na začiatku</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="101"/>
        <source>Store/show history</source>
        <translation>Uložiť/zobraziť históriu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="81"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Upozornenie:&lt;/b&gt; Veľkosť top-level widgetov je obmedzená na 2/3 výšky a šírky pracovnej plochy.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="84"/>
        <source>Show list with:</source>
        <translation>Počet položiek v zozname:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="91"/>
        <source> item(s)</source>
        <translation> položky</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="115"/>
        <source>Clear input on launching</source>
        <translation>Vymazať vstup pri spustení</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="132"/>
        <source>Shortcut:</source>
        <translation>Klávesová skratka:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Horný okraj obrazovky</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Stred obrazovky</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>On Wayland, the shortcut has to be added
in the compositor settings for &apos;lxqt-runner&apos;.</source>
        <translation>V systéme Wayland je potrebné pridať skratku
v nastaveniach kompozitora pre &apos;lxqt-runner&apos;.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="83"/>
        <source>Focused screen</source>
        <translation>Aktuálna obrazovka</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="87"/>
        <source>Always on screen %1</source>
        <translation>Vždy na obrazovke %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="96"/>
        <source>Reset</source>
        <translation>Zrušiť zmeny</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Spúšťač aplikácií </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Configure</source>
        <translation>Nastaviť</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="113"/>
        <source>Clear History</source>
        <translation>Vymazať históriu</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="523"/>
        <source>Show/hide runner dialog</source>
        <translation>Zobraziť/skryť okno Runneru</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>História</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Skopírovať výsledok výpočtu do schránky</translation>
    </message>
</context>
</TS>
